@@ -21,7 +21,6 @@ from cinderclient import exceptions as cinder_exceptions
 from eventlet import greenthread
 from eventlet.timeout import Timeout
 from oslo_log import log as logging
-from oslo_utils import netutils
 from swiftclient.client import ClientException
 
 from trove.backup import models as bkup_models
@@ -478,9 +477,8 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                                        access=None):
         """Prepare the networks for the trove instance.
 
-        the params are all passed from trove-taskmanager.
-
-        Exception is raised if any error happens.
+        'nics' contains the networks that management network always comes at
+        last.
         """
         LOG.info("Preparing networks for the instance %s", self.id)
         security_group = None
@@ -513,6 +511,9 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
                      self.id)
             networks.append({"port-id": port_id})
 
+        if not CONF.management_networks and not networks:
+            return None
+
         # Create port in the user defined network, associate floating IP if
         # needed
         if len(networks) > 1 or not CONF.management_networks:
@@ -567,13 +568,13 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
 
         backup_info = None
         if backup_id is not None:
-                backup = bkup_models.Backup.get_by_id(self.context, backup_id)
-                backup_info = {'id': backup_id,
-                               'instance_id': backup.instance_id,
-                               'location': backup.location,
-                               'type': backup.backup_type,
-                               'checksum': backup.checksum,
-                               }
+            backup = bkup_models.Backup.get_by_id(self.context, backup_id)
+            backup_info = {'id': backup_id,
+                           'instance_id': backup.instance_id,
+                           'location': backup.location,
+                           'type': backup.backup_type,
+                           'checksum': backup.checksum,
+                           }
         self._guest_prepare(flavor['ram'], volume_info,
                             packages, databases, users, backup_info,
                             config.config_contents, root_password,
@@ -764,11 +765,11 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
         """
         service = InstanceServiceStatus.find_by(instance_id=self.id)
         status = service.get_status()
-        LOG.debug("Service status of instance %(instance)s is %(status)s",
-                  {"instance": self.id, "status": status})
+
         if (status == rd_instance.ServiceStatuses.RUNNING or
-           status == rd_instance.ServiceStatuses.INSTANCE_READY):
-                return True
+                status == rd_instance.ServiceStatuses.INSTANCE_READY or
+                status == rd_instance.ServiceStatuses.HEALTHY):
+            return True
         elif status not in [rd_instance.ServiceStatuses.NEW,
                             rd_instance.ServiceStatuses.BUILDING,
                             rd_instance.ServiceStatuses.UNKNOWN,
@@ -786,7 +787,6 @@ class FreshInstanceTasks(FreshInstance, NotifyMixin, ConfigurationMixin):
             )
 
         server_status = server.status
-        LOG.debug("Server status of instance %s is %s", self.id, server_status)
         if server_status in [InstanceStatus.ERROR,
                              InstanceStatus.FAILED]:
             server_fault_message = 'No fault found'
@@ -1161,50 +1161,6 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
         LOG.debug("Calling make_read_only on %s", self.id)
         self.guest.make_read_only(read_only)
 
-    def _get_floating_ips(self):
-        """Returns floating ips as a dict indexed by the ip."""
-        floating_ips = {}
-        network_floating_ips = self.neutron_client.list_floatingips()
-        for ip in network_floating_ips.get('floatingips'):
-            floating_ips.update(
-                {ip.get('floating_ip_address'): ip.get('id')})
-        LOG.debug("In _get_floating_ips(), returning %s", floating_ips)
-        return floating_ips
-
-    def detach_public_ips(self):
-        LOG.debug("Begin detach_public_ips for instance %s", self.id)
-        removed_ips = []
-        floating_ips = self._get_floating_ips()
-        for ip in self.get_visible_ip_addresses():
-            if ip in floating_ips:
-                fip_id = floating_ips[ip]
-                self.neutron_client.update_floatingip(
-                    fip_id, {'floatingip': {'port_id': None}})
-                removed_ips.append(fip_id)
-        return removed_ips
-
-    def attach_public_ips(self, ips):
-        LOG.debug("Begin attach_public_ips for instance %s", self.id)
-        server_id = self.db_info.compute_instance_id
-
-        # NOTE(zhaochao): in Nova's addFloatingIp, the new floating ip will
-        # always be associated with the first IPv4 fixed address of the Nova
-        # instance, we're doing the same thing here, after add_floating_ip is
-        # removed from novaclient.
-        server_ports = (self.neutron_client.list_ports(device_id=server_id)
-                        .get('ports'))
-        fixed_address, port_id = next(
-            (fixed_ip['ip_address'], port['id'])
-            for port in server_ports
-            for fixed_ip in port.get('fixed_ips')
-            if netutils.is_valid_ipv4(fixed_ip['ip_address']))
-
-        for fip_id in ips:
-            self.neutron_client.update_floatingip(
-                fip_id, {'floatingip': {
-                    'port_id': port_id,
-                    'fixed_ip_address': fixed_address}})
-
     def enable_as_master(self):
         LOG.debug("Calling enable_as_master on %s", self.id)
         flavor = self.nova_client.flavors.get(self.flavor_id)
@@ -1244,34 +1200,8 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
                 # Also we check guest state before issuing reboot
                 LOG.debug(str(e))
 
-            # Wait for the mysql stopped.
-            def _datastore_is_offline():
-                self._refresh_datastore_status()
-                return (
-                    self.datastore_status_matches(
-                        rd_instance.ServiceStatuses.SHUTDOWN) or
-                    self.datastore_status_matches(
-                        rd_instance.ServiceStatuses.CRASHED)
-                )
-
-            try:
-                utils.poll_until(
-                    _datastore_is_offline,
-                    sleep_time=3,
-                    time_out=CONF.reboot_time_out
-                )
-            except exception.PollTimeOut:
-                LOG.error("Cannot reboot instance, DB status is %s",
-                          self.datastore_status.status)
-                return
-
-            LOG.debug("The guest service status is %s.",
-                      self.datastore_status.status)
-
             LOG.info("Rebooting instance %s.", self.id)
             self.server.reboot()
-            # Poll nova until instance is active
-            reboot_time_out = CONF.reboot_time_out
 
             def update_server_info():
                 self.refresh_compute_server_info()
@@ -1280,7 +1210,7 @@ class BuiltInstanceTasks(BuiltInstance, NotifyMixin, ConfigurationMixin):
             utils.poll_until(
                 update_server_info,
                 sleep_time=3,
-                time_out=reboot_time_out)
+                time_out=CONF.reboot_time_out)
 
             # Set the status to PAUSED. The guest agent will reset the status
             # when the reboot completes and MySQL is running.
@@ -1455,6 +1385,14 @@ class BackupTasks(object):
     @classmethod
     def delete_backup(cls, context, backup_id):
         """Delete backup from swift."""
+        def _delete(backup):
+            backup.deleted = True
+            backup.deleted_at = timeutils.utcnow()
+            # Set datastore_version_id to None so that datastore_version could
+            # be deleted.
+            backup.datastore_version_id = None
+            backup.save()
+
         LOG.info("Deleting backup %s.", backup_id)
         backup = bkup_models.Backup.get_by_id(context, backup_id)
         try:
@@ -1462,11 +1400,11 @@ class BackupTasks(object):
             if filename:
                 BackupTasks.delete_files_from_swift(context, filename)
         except ValueError:
-            backup.delete()
+            _delete(backup)
         except ClientException as e:
             if e.http_status == 404:
                 # Backup already deleted in swift
-                backup.delete()
+                _delete(backup)
             else:
                 LOG.exception("Error occurred when deleting from swift. "
                               "Details: %s", e)
@@ -1475,7 +1413,7 @@ class BackupTasks(object):
                 raise TroveError(_("Failed to delete swift object for backup "
                                    "%s.") % backup_id)
         else:
-            backup.delete()
+            _delete(backup)
         LOG.info("Deleted backup %s successfully.", backup_id)
 
 
@@ -1760,7 +1698,8 @@ class ResizeVolumeAction(object):
                                       'old_volume_size': self.old_size,
                                       'new_size': self.new_size})
 
-        if self.instance.server.status == InstanceStatus.ACTIVE:
+        if self.instance.server.status in [InstanceStatus.ACTIVE,
+                                           InstanceStatus.HEALTHY]:
             self._resize_active_volume()
             self.instance.reset_task_status()
             # send usage event for size reported by cinder
@@ -1776,13 +1715,17 @@ class ResizeVolumeAction(object):
                                       ).notify()
         else:
             self.instance.reset_task_status()
-            msg = _("Failed to resize instance %(id)s volume for server "
-                    "%(server_id)s. The instance must be in state %(state)s "
-                    "not %(inst_state)s.") % {
-                        'id': self.instance.id,
-                        'server_id': self.instance.server.id,
-                        'state': InstanceStatus.ACTIVE,
-                        'inst_state': self.instance.server.status}
+            msg = (
+                "Failed to resize instance %(id)s volume for server "
+                "%(server_id)s. The instance must be in state %(state)s "
+                "not %(inst_state)s." %
+                {
+                    'id': self.instance.id,
+                    'server_id': self.instance.server.id,
+                    'state': [InstanceStatus.ACTIVE, InstanceStatus.HEALTHY],
+                    'inst_state': self.instance.server.status
+                }
+            )
             raise TroveError(msg)
 
 
