@@ -75,7 +75,7 @@ class fake_Server(object):
         self.files = None
         self.userdata = None
         self.block_device_mapping_v2 = None
-        self.status = 'ACTIVE'
+        self.status = 'HEALTHY'
         self.key_name = None
 
 
@@ -395,7 +395,7 @@ class FreshInstanceTasksTest(BaseFreshInstanceTasksTest):
     @patch.object(taskmanager_models.FreshInstanceTasks, '_build_volume_info')
     @patch.object(taskmanager_models.FreshInstanceTasks, '_guest_prepare')
     @patch.object(template, 'SingleInstanceConfigTemplate')
-    @patch('trove.common.clients.neutron_client')
+    @patch('trove.common.clients_admin.neutron_client_trove_admin')
     def test_create_instance_with_mgmt_port(self,
                                             mock_neutron_client,
                                             mock_single_instance_template,
@@ -723,7 +723,7 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
                                  volume_id=VOLUME_ID)
 
         # this is used during the final check of whether the resize successful
-        db_instance.server_status = 'ACTIVE'
+        db_instance.server_status = 'HEALTHY'
         self.db_instance = db_instance
         self.dm_dv_load_by_uuid_patch = patch.object(
             datastore_models.DatastoreVersion, 'load_by_uuid', MagicMock(
@@ -750,7 +750,7 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
             spec=novaclient.v2.servers.ServerManager)
         self.stub_running_server = MagicMock(
             spec=novaclient.v2.servers.Server)
-        self.stub_running_server.status = 'ACTIVE'
+        self.stub_running_server.status = 'HEALTHY'
         self.stub_running_server.flavor = {'id': 6, 'ram': 512}
         self.stub_verifying_server = MagicMock(
             spec=novaclient.v2.servers.Server)
@@ -858,19 +858,6 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
         self.instance_task.server.reboot.assert_any_call()
         self.instance_task.set_datastore_status_to_paused.assert_any_call()
 
-    @patch.object(utils, 'poll_until')
-    @patch('trove.taskmanager.models.LOG')
-    def test_reboot_datastore_not_ready(self, mock_logging, mock_poll):
-        mock_poll.side_effect = PollTimeOut
-        self.instance_task.server.reboot = Mock()
-        self.instance_task.set_datastore_status_to_paused = Mock()
-
-        self.instance_task.reboot()
-
-        self.instance_task._guest.stop_db.assert_any_call()
-        assert not self.instance_task.server.reboot.called
-        assert not self.instance_task.set_datastore_status_to_paused.called
-
     @patch.object(BaseInstance, 'update_db')
     def test_detach_replica(self, mock_update_db):
         with patch.object(self.instance_task, 'reset_task_status') as tr_mock:
@@ -939,34 +926,6 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
             self.assertRaises(GuestError, self.instance_task.attach_replica,
                               Mock())
 
-    def test_get_floating_ips(self):
-        floating_ips = self.instance_task._get_floating_ips()
-        self.assertEqual({'192.168.10.1': 'fake-floatingip-id'},
-                         floating_ips)
-
-    @patch.object(BaseInstance, 'get_visible_ip_addresses',
-                  return_value=['192.168.10.1'])
-    def test_detach_public_ips(self, mock_address):
-        removed_ips = self.instance_task.detach_public_ips()
-        self.assertEqual(['fake-floatingip-id'], removed_ips)
-        mock_update_floatingip = (self.instance_task.neutron_client
-                                  .update_floatingip)
-        mock_update_floatingip.assert_called_once_with(
-            removed_ips[0], {'floatingip': {'port_id': None}})
-
-    def test_attach_public_ips(self):
-        self.instance_task.attach_public_ips(['fake-floatingip-id'])
-        mock_list_ports = (self.instance_task.neutron_client
-                           .list_ports)
-        mock_list_ports.assert_called_once_with(device_id='computeinst-id-1')
-
-        mock_update_floatingip = (self.instance_task.neutron_client
-                                  .update_floatingip)
-        mock_update_floatingip.assert_called_once_with(
-            'fake-floatingip-id',
-            {'floatingip': {'port_id': 'fake-port-id',
-                            'fixed_ip_address': '10.0.0.1'}})
-
     @patch.object(BaseInstance, 'update_db')
     def test_enable_as_master(self, mock_update_db):
         test_func = self.instance_task._guest.enable_as_master
@@ -1069,7 +1028,8 @@ class BackupTasksTest(trove_testtools.TestCase):
         self.backup.location = ''
         taskmanager_models.BackupTasks.delete_backup('dummy context',
                                                      self.backup.id)
-        self.backup.delete.assert_any_call()
+
+        self.assertTrue(self.backup.deleted)
 
     @patch('trove.taskmanager.models.LOG')
     @patch('trove.common.clients.create_swift_client')
